@@ -1,4 +1,4 @@
-"""
+'''
 # aws-iot-lambda-dynamodb module
 
 <!--BEGIN STABILITY BANNER-->---
@@ -67,7 +67,7 @@ new IotToLambdaToDynamoDB(scope: Construct, id: string, props: IotToLambdaToDyna
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.|
+|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.|
 |lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|User provided props to override the default props for the Lambda function.|
 |iotTopicRuleProps|[`iot.CfnTopicRuleProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iot.CfnTopicRuleProps.html)|User provided props to override the default props|
 |dynamoTableProps?|[`dynamodb.TableProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-dynamodb.TableProps.html)|Optional user provided props to override the default props for DynamoDB Table|
@@ -114,7 +114,7 @@ Out of the box implementation of the Construct without any override will set the
 
 
 © Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-"""
+'''
 import abc
 import builtins
 import datetime
@@ -149,19 +149,19 @@ class IotToLambdaToDynamoDB(
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
         table_permissions: typing.Optional[builtins.str] = None,
     ) -> None:
-        """
+        '''
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
         :param iot_topic_rule_props: User provided props to override the default props. Default: - Default props are used
         :param dynamo_table_props: Optional user provided props to override the default props. Default: - Default props are used
-        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
+        :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
         :param table_permissions: Optional table permissions to grant to the Lambda function. One of the following may be specified: "All", "Read", "ReadWrite", "Write". Default: - Read/write access is given to the Lambda function if no value is specified.
 
         :access: public
         :since: 0.8.0
         :summary: Constructs a new instance of the IotToLambdaToDynamoDB class.
-        """
+        '''
         props = IotToLambdaToDynamoDBProps(
             iot_topic_rule_props=iot_topic_rule_props,
             dynamo_table_props=dynamo_table_props,
@@ -170,7 +170,7 @@ class IotToLambdaToDynamoDB(
             table_permissions=table_permissions,
         )
 
-        jsii.create(IotToLambdaToDynamoDB, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="dynamoTable")
@@ -209,15 +209,15 @@ class IotToLambdaToDynamoDBProps:
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
         table_permissions: typing.Optional[builtins.str] = None,
     ) -> None:
-        """
+        '''
         :param iot_topic_rule_props: User provided props to override the default props. Default: - Default props are used
         :param dynamo_table_props: Optional user provided props to override the default props. Default: - Default props are used
-        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
+        :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
         :param table_permissions: Optional table permissions to grant to the Lambda function. One of the following may be specified: "All", "Read", "ReadWrite", "Write". Default: - Read/write access is given to the Lambda function if no value is specified.
 
         :summary: The properties for the IotToLambdaToDynamoDB class.
-        """
+        '''
         if isinstance(iot_topic_rule_props, dict):
             iot_topic_rule_props = aws_cdk.aws_iot.CfnTopicRuleProps(**iot_topic_rule_props)
         if isinstance(dynamo_table_props, dict):
@@ -238,29 +238,29 @@ class IotToLambdaToDynamoDBProps:
 
     @builtins.property
     def iot_topic_rule_props(self) -> aws_cdk.aws_iot.CfnTopicRuleProps:
-        """User provided props to override the default props.
+        '''User provided props to override the default props.
 
         :default: - Default props are used
-        """
+        '''
         result = self._values.get("iot_topic_rule_props")
         assert result is not None, "Required property 'iot_topic_rule_props' is missing"
         return typing.cast(aws_cdk.aws_iot.CfnTopicRuleProps, result)
 
     @builtins.property
     def dynamo_table_props(self) -> typing.Optional[aws_cdk.aws_dynamodb.TableProps]:
-        """Optional user provided props to override the default props.
+        '''Optional user provided props to override the default props.
 
         :default: - Default props are used
-        """
+        '''
         result = self._values.get("dynamo_table_props")
         return typing.cast(typing.Optional[aws_cdk.aws_dynamodb.TableProps], result)
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
-        """Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
+        '''Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error.
 
         :default: - None
-        """
+        '''
         result = self._values.get("existing_lambda_obj")
         return typing.cast(typing.Optional[aws_cdk.aws_lambda.Function], result)
 
@@ -268,21 +268,21 @@ class IotToLambdaToDynamoDBProps:
     def lambda_function_props(
         self,
     ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
-        """User provided props to override the default props for the Lambda function.
+        '''User provided props to override the default props for the Lambda function.
 
         :default: - Default props are used
-        """
+        '''
         result = self._values.get("lambda_function_props")
         return typing.cast(typing.Optional[aws_cdk.aws_lambda.FunctionProps], result)
 
     @builtins.property
     def table_permissions(self) -> typing.Optional[builtins.str]:
-        """Optional table permissions to grant to the Lambda function.
+        '''Optional table permissions to grant to the Lambda function.
 
         One of the following may be specified: "All", "Read", "ReadWrite", "Write".
 
         :default: - Read/write access is given to the Lambda function if no value is specified.
-        """
+        '''
         result = self._values.get("table_permissions")
         return typing.cast(typing.Optional[builtins.str], result)
 
